"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const components_return_once_1 = __importDefault(require("./rules/components-return-once"));
const event_handlers_1 = __importDefault(require("./rules/event-handlers"));
const imports_1 = __importDefault(require("./rules/imports"));
const jsx_no_duplicate_props_1 = __importDefault(require("./rules/jsx-no-duplicate-props"));
const jsx_no_script_url_1 = __importDefault(require("./rules/jsx-no-script-url"));
const jsx_no_undef_1 = __importDefault(require("./rules/jsx-no-undef"));
const jsx_uses_vars_1 = __importDefault(require("./rules/jsx-uses-vars"));
const no_destructure_1 = __importDefault(require("./rules/no-destructure"));
const no_innerhtml_1 = __importDefault(require("./rules/no-innerhtml"));
const no_proxy_apis_1 = __importDefault(require("./rules/no-proxy-apis"));
const no_react_deps_1 = __importDefault(require("./rules/no-react-deps"));
const no_react_specific_props_1 = __importDefault(require("./rules/no-react-specific-props"));
const no_unknown_namespaces_1 = __importDefault(require("./rules/no-unknown-namespaces"));
const prefer_classlist_1 = __importDefault(require("./rules/prefer-classlist"));
const prefer_for_1 = __importDefault(require("./rules/prefer-for"));
const prefer_show_1 = __importDefault(require("./rules/prefer-show"));
const reactivity_1 = __importDefault(require("./rules/reactivity"));
const self_closing_comp_1 = __importDefault(require("./rules/self-closing-comp"));
const style_prop_1 = __importDefault(require("./rules/style-prop"));
const allRules = {
    "components-return-once": components_return_once_1.default,
    "event-handlers": event_handlers_1.default,
    imports: imports_1.default,
    "jsx-no-duplicate-props": jsx_no_duplicate_props_1.default,
    "jsx-no-undef": jsx_no_undef_1.default,
    "jsx-no-script-url": jsx_no_script_url_1.default,
    "jsx-uses-vars": jsx_uses_vars_1.default,
    "no-destructure": no_destructure_1.default,
    "no-innerhtml": no_innerhtml_1.default,
    "no-proxy-apis": no_proxy_apis_1.default,
    "no-react-deps": no_react_deps_1.default,
    "no-react-specific-props": no_react_specific_props_1.default,
    "no-unknown-namespaces": no_unknown_namespaces_1.default,
    "prefer-classlist": prefer_classlist_1.default,
    "prefer-for": prefer_for_1.default,
    "prefer-show": prefer_show_1.default,
    reactivity: reactivity_1.default,
    "self-closing-comp": self_closing_comp_1.default,
    "style-prop": style_prop_1.default,
};
const plugin = {
    rules: allRules,
    configs: {
        recommended: {
            plugins: ["solid"],
            env: {
                browser: true,
                es6: true,
            },
            parserOptions: {
                sourceType: "module",
                ecmaFeatures: {
                    jsx: true,
                    impliedStrict: true,
                },
            },
            rules: {
                "solid/jsx-no-duplicate-props": 2,
                "solid/jsx-no-undef": 2,
                "solid/jsx-uses-vars": 2,
                "solid/no-unknown-namespaces": 2,
                "solid/no-innerhtml": 2,
                "solid/jsx-no-script-url": 2,
                "solid/components-return-once": 1,
                "solid/no-destructure": 2,
                "solid/prefer-for": 2,
                "solid/reactivity": 1,
                "solid/event-handlers": 1,
                "solid/imports": 1,
                "solid/style-prop": 1,
                "solid/no-react-deps": 1,
                "solid/no-react-specific-props": 1,
                "solid/self-closing-comp": 1,
                "solid/prefer-show": 0,
                "solid/no-proxy-apis": 0,
                "solid/prefer-classlist": 0,
            },
        },
        typescript: {
            plugins: ["solid"],
            env: {
                browser: true,
                es6: true,
            },
            rules: {
                "solid/jsx-no-duplicate-props": 2,
                "solid/jsx-no-undef": [2, { typescriptEnabled: true }],
                "solid/jsx-uses-vars": 2,
                "solid/no-innerhtml": 2,
                "solid/jsx-no-script-url": 2,
                "solid/components-return-once": 1,
                "solid/no-destructure": 2,
                "solid/prefer-for": 2,
                "solid/reactivity": 1,
                "solid/event-handlers": 1,
                "solid/imports": 1,
                "solid/style-prop": 1,
                "solid/no-react-deps": 1,
                "solid/no-react-specific-props": 1,
                "solid/self-closing-comp": 1,
                "solid/no-unknown-namespaces": 0,
                "solid/prefer-show": 0,
                "solid/no-proxy-apis": 0,
                "solid/prefer-classlist": 0,
            },
        },
    },
};
module.exports = plugin;
